@@ -19,14 +19,13 @@
 
 #include "abstractrunner.h"
 
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QHash>
 #include <QMenu>
 #include <QMimeData>
 #include <QMutex>
 #include <QMutexLocker>
 #include <QTimer>
-#include <QDebug>
 
 #include "krunner_debug.h"
 #include <kplugininfo.h>
@@ -201,8 +200,12 @@ void AbstractRunner::clearActions()
 
 QMimeData *AbstractRunner::mimeDataForMatch(const QueryMatch &match)
 {
-    Q_UNUSED(match)
-    return nullptr;
+        if (match.urls().isEmpty()) {
+        return nullptr;
+    }
+    QMimeData *result = new QMimeData();
+    result->setUrls(match.urls());
+    return result;
 }
 
 bool AbstractRunner::hasRunOptions()
